@@ -10,6 +10,9 @@ from boastlabs.functions.retriable.execution.events.handler import Event, Trigge
 from boastlabs.functions.retriable.execution.config import Status
 
 
+MAX_ATTEMPTS = 50
+
+
 class EventHandling(object):
 
     def __init__(self, db, event_ref: DocumentReference):
@@ -50,7 +53,7 @@ class EventHandling(object):
                 raise IncompatibleApiVersionException(found_api_version=event.set_api_version(),
                                                       current_api_version=__version__)
 
-        handle_in_transaction(transaction=firestore_v1.Transaction(client=self.db))
+        handle_in_transaction(transaction=firestore_v1.Transaction(client=self.db, max_attempts=MAX_ATTEMPTS))
 
 
 class EventWorkDone(object):
@@ -88,4 +91,4 @@ class EventWorkDone(object):
                 'event_type': 'trigger'
             })
 
-        handle_in_transaction(transaction=firestore_v1.Transaction(client=self.db))
+        handle_in_transaction(transaction=firestore_v1.Transaction(client=self.db, max_attempts=MAX_ATTEMPTS))
